@@ -61,48 +61,48 @@ function(data,fondMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,varFlux,filtr
 
     analyse<-k_oursins(fondMaille,names(fondMaille)[1],data,"CODE1","CODE2",varFlux,decalageAllerRetour,decalageCentroid)
 
-    analyse_WGS84 <- st_transform(analyse[[1]],"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+    analyse_WGS84 <- st_transform(analyse[[1]],crs=4326)
 
     # Fonds habillages
 
     if(emprise=="FRM")
     {
-      fond_pays <- st_transform(sf_paysm(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-      fond_france <- st_transform(sf_fram(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+      fond_pays <- st_transform(sf_paysm(),crs=4326)
+      fond_france <- st_transform(sf_fram(),crs=4326)
     }else if(emprise!="999")
     {
       if(emprise=="971")
       {
-        fond_france <- st_transform(sf_reg01(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg01(),crs=4326)
         fond_pays <- fond_france
       }
       if(emprise=="972")
       {
-        fond_france <- st_transform(sf_reg02(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg02(),crs=4326)
         fond_pays <- fond_france
       }
       if(emprise=="973")
       {
-        fond_france <- st_transform(sf_reg03(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
-        fond_pays <- st_transform(sf_pays973(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg03(),crs=4326)
+        fond_pays <- st_transform(sf_pays973(),crs=4326)
       }
       if(emprise=="974")
       {
-        fond_france <- st_transform(sf_reg04(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg04(),crs=4326)
         fond_pays <- fond_france
       }
       if(emprise=="976")
       {
-        fond_france <- st_transform(sf_reg06(),"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+        fond_france <- st_transform(sf_reg06(),crs=4326)
         fond_pays <- fond_france
       }
     }else if(emprise=="999")
     {
-      fond_etranger <- st_transform(fondEtranger,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+      fond_etranger <- st_transform(fondEtranger,crs=4326)
       fond_pays <- fond_etranger
     }else{}
 
-    maille_WGS84 <- st_transform(fondMaille,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+    maille_WGS84 <- st_transform(fondMaille,crs=4326)
 
     if(!is.null(zoomMaille))
     {
@@ -121,7 +121,7 @@ function(data,fondMaille,fondSuppl=NULL,idDataDepart,idDataArrivee,varFlux,filtr
 
     if(!is.null(fondSuppl))
     {
-      fond_territoire <- st_transform(fondSuppl,"+init=epsg:4326 +proj=longlat +ellps=WGS84")
+      fond_territoire <- st_transform(fondSuppl,crs=4326)
     }
 
     if(filtreMajeurs>nrow(analyse_WGS84))
