@@ -284,8 +284,8 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
 
     analyse_classes <- merge(fondMaille[,c("CODE","geometry")],data,by="CODE")
 
-    max <- max(as.data.frame(analyse_classes)[,varRatio])
-    min <- min(as.data.frame(analyse_classes)[,varRatio])
+    max <- max(as.data.frame(analyse_classes)[,varRatio], na.rm = TRUE)
+    min <- min(as.data.frame(analyse_classes)[,varRatio], na.rm = TRUE)
 
     if(is.null(bornes))
     {
@@ -299,7 +299,7 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
         carac_bornes <- calcul_bornes(as.data.frame(analyse_classes),bornes_analyse,varRatio,nbClasses,methode,stylePalette=stylePalette,palettePos=palettePos,paletteNeg=paletteNeg)
       }
       bornes <- carac_bornes[[1]]
-      bornes[1] <- max(as.numeric(as.data.frame(analyse_classes)[,varRatio]))
+      bornes[1] <- max(as.numeric(as.data.frame(analyse_classes)[,varRatio]), na.rm = TRUE)
       bornes_sansext <- bornes[-1]
       bornes_sansext <- bornes_sansext[-length(bornes_sansext)]
       bornes_sansext <- sort(bornes_sansext, decreasing = TRUE)
